#
# Computation and graphing of CIs for decoy/attraction experiments
# Evanthia Dimara (using functions from Pierre Dragicevic, Jan 2016, attraction effect)
#

# Several helper functionns have been put in a separate R file for legibility. Execute the code here.
source('decoyCIsFunctions.R')

#
# Some parameters of the report
#
reportCumulatedAttractionEffects <- TRUE
reportAverageAttractionEffects <- FALSE
sigDigits <- NA # Use NA for a somehow 'clever' use of significant digits

plotRange <- c(-.25, .25)

###############
# Experiment 3
###############

# Observations copied from http://evanthiadimara.com/experiment3/participants/statistics
# and http://evanthiadimara.com/crowdflower4/Participants/statistics

oldbet.attraction.scores <- c(0.1, 0, -0.1, -0.2, -0.2, -0.25, 0.7, 0.2, 0.1, 0.1, 0.2, -0.2, 0.4, 0.2, 0.25, -0.1, -0.2, -0.2, 0, 1, 0.1, 0.1, 0.1, 0.1, 0.3, 0.4, 0, 0, 0, -0.1, 0, -0.1, 0.4, 0.2, 0.1, 0.1, 0.1, 0.2, -0.1, 0, 0.4, 0.05, 0.3, 0.35, 0.1, 0.35, 0.6, 0.1, -0.1, 0.1, 0, -0.2, 0.3, 0.25, 0.2, 0.1, 0.4, 0.1, 0.8, 0.4, -0.1, 0.2, 0.2, -0.1, 0.25, 0.6, 0.5, -0.1, 0.15, -0.1, 0.9, 0.4, 0.1)
bet.selection.attraction.scores <- c(0, 0, -0.1, 0, 0.2, 0.1, -0.3, 0.6, 0.2, 0.35, 0, 0.1, 0.2, 0.2, 0.2, 0, 0, 0.1, 0.1, 0.2, 0.15, 0, 0.4, 0.6, 0.1, 0, 0, -0.2, 0, 0, -0.1, 0, 0, 0.4, 0.1, 0.1, 0.2, 0.2, 0, 0.2, -0.1, 0, 0, -0.2, -0.15, 0, -0.1, 0.8, 0, 0, 0.15, 0, 0, 0, 0.1, 0.2, 0.1, 0.5, 0.1, 0, 0, 0, 0, 0, 0.3, -0.3, 0.25, 0.1, 0, -0.1, -0.35, 0, 0.7, 0, -0.5, 0.2, 0, 0.35, 0.1, 0, -0.1, 0.1, 0.2, 0.1, 0, 0, 0.3, -0.1, -0.1, 0.1, -0.1, 0, 0, 0, 0, 0.1, 0.1, 0, -0.1, 0.65, 0.3, 0)
bet.deletion.attraction.scores <- c(-0.1, 0, 0, 0, 0.5, 0, -0.15, 0.3, -0.3, 0, 0, -0.1, 0.25, 0, 0, 0, -0.1, -0.1, -0.1, 0, 0, 0.1, 0, 0.1, 0.3, 0, 0, 0.3, -0.3, -0.2, 0.1, 0, -0.3, 0, 0, 0, 0.1, 0, -0.1, 0, -0.2, 0.1, -0.1, 0, 0.5, 0, -0.05, 0.2, 0.2, 0.1, 0, 0, 0.1, 0.1, 0, 0.15, 0, 0, 0.1, 0, 0, -0.1, 0, 0.2, 0.1, 0, 0, -0.2, 0, 0, -0.2, 0.1, 0, 0, -0.05, 0.1, 0.3, -0.2, 0, 0, 0, 0, 0, 0.1, 0, -0.2, 0, 0.05, 0, 0, 0.2, -0.1, 0.2, 0.1, 0, -0.1, -0.1, -0.2, -0.1, 0, 0)

diff.selection.deletion.attraction.scores <- bet.selection.attraction.scores - bet.deletion.attraction.scores 

###############
# Analysis
###############

#
# 1. Double-check participant counts for safety (and compare with Anthi's email 13 Jan 2015)
#


total_participants_3 <- length(oldbet.attraction.scores)
total_participants_selection <- length(bet.selection.attraction.scores)
total_participants_deletion <- length(bet.deletion.attraction.scores)

cat("Total participants in OLD Bets exp: ", total_participants_3, " (should be 73)\n")
cat("Total participants in selection exp: ", total_participants_selection, " (should be 102)\n")
cat("Total participants in deletion exp: ", total_participants_deletion, " (should be 101)\n")


#
# 2. Prepare the 'results' table and declare functions to add effects of interest as new rows of the table
#

# The data frame that will contains all data + methods to add new rows
results <- data.frame(label = character(0), point = numeric(0), ci.lower = numeric(0), ci.upper = numeric(0))

# Add a difference between proportions as a result
add.prop.diff <- function(results, label, x1, x2, y1, y2, multiply = 1) {
  diff_prop_ci <- diffpropCI(x1, x1 + x2, y1, y1 + y2) * multiply
  cat(pad(label, -32), format_ci(diff_prop_ci, sigdigits=sigDigits, width=result_width, percent=TRUE), "\n", sep='')
  rbind(results, data.frame(label = label, point = diff_prop_ci[1], ci.lower = diff_prop_ci[2], ci.upper = diff_prop_ci[3]))
}

# Add a sample mean as a result
add.mean <- function(results, label, obs, multiply = 1, percent_output = FALSE) {
  mean_ci <- meanCI(obs) * multiply
  cat(pad(label, -32), format_ci(mean_ci, sigdigits=sigDigits, width=result_width, percent=percent_output), "\n", sep='')
  rbind(results, data.frame(label = label, point = mean_ci[1], ci.lower = mean_ci[2], ci.upper = mean_ci[3]))
}

# Estimate the required width for the results column, for cleaner text output
result_width <- ifelse(is.na(sigDigits), 22, 22 + (sigDigits - 2) * 3)

cat("\n")

#
# 3. Compute and add all effects of interest to the 'results' table
#

## Effects for experiment 3

if (reportCumulatedAttractionEffects) results <- add.mean(
  results,
  'Old Bets, score analysis',
  oldbet.attraction.scores,
  percent_output = T,
  multiply = 1.0
)

if (reportCumulatedAttractionEffects) results <- add.mean(
  results,
  'Selection Bets, score analysis',
  bet.selection.attraction.scores,
  percent_output = T,
  multiply = 1.0
)


if (reportCumulatedAttractionEffects) results <- add.mean(
  results,
  'Deletion Bets, score analysis',
  bet.deletion.attraction.scores,
  percent_output = T,
  multiply = 1.0
)


if (reportCumulatedAttractionEffects) results <- add.mean(
  results,
  'Difference Selection - Deletion, score analysis',
  diff.selection.deletion.attraction.scores ,
  percent_output = T,
  multiply = 1.0
)

#
# 4. Derive effect types from labels (used to attribute colors in the plotting function)
#

results$type <- factor(rep('Other', nrow(results)), ordered = TRUE, levels = c(
  'Simple attraction effect',
  'Cumulated attraction effect',
  'Average attraction effect',
  'Other'
))

palette <- c("#888888", "#EE4444", "#000000", "#4466FF")

#
# 5. Plot all effects and their confidence intervals
#

# Choose which effects to plot
rows.to.plot <- 1:(nrow(results)) # plot all but the within-pair consistency score

results.to.plot <- results[rows.to.plot,]

# Simplify the ggplot visual theme
theme_set(theme_bw() + theme(
  axis.title = element_blank(),
  axis.text.y = element_blank(),
  axis.ticks = element_blank(),
  panel.grid.major.y = element_blank(),
  panel.grid.minor.y = element_blank(),
  panel.grid.major.x = element_line(color = "#000000", size = 0.05),
  panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
  panel.border = element_blank(),
  legend.key.size = unit(5,"mm"), 
  plot.margin=unit(c(0.2, 0.2, 0.2, 0.2),"cm"),
  text = element_text(size=17)))

# Plot all confidence intervals
p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label, col=type)) +
  scale_color_manual(values=palette) +
  geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=0.9) +
  geom_point(size=0.9*5, colour="#ffffff", pch=21) +
  geom_text(y=plotRange[1], hjust=0, size=5.0) +
  geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
  scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
  coord_flip()

print(p)
